summaryrefslogtreecommitdiffstats
path: root/src/textprop.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/textprop.c')
-rw-r--r--src/textprop.c13
1 files changed, 9 insertions, 4 deletions
diff --git a/src/textprop.c b/src/textprop.c
index ff96833f6c..80b0151679 100644
--- a/src/textprop.c
+++ b/src/textprop.c
@@ -608,12 +608,12 @@ get_text_props(buf_T *buf, linenr_T lnum, char_u **props, int will_change)
}
/*
* Return the number of text properties with "below" alignment in line "lnum".
* A "right" aligned property also goes below after a "below" or other "right"
* aligned property.
*/
int
-prop_count_below(buf_T *buf, linenr_T lnum)
+prop_count_above_below(buf_T *buf, linenr_T lnum)
{
char_u *props;
int count = get_text_props(buf, lnum, &props, FALSE);
@@ -636,6 +636,11 @@ prop_count_below(buf_T *buf, linenr_T lnum)
next_right_goes_below = TRUE;
++result;
}
+ else if (prop.tp_flags & TP_FLAG_ALIGN_ABOVE)
+ {
+ next_right_goes_below = FALSE;
+ ++result;
+ }
else if (prop.tp_flags & TP_FLAG_ALIGN_RIGHT)
next_right_goes_below = TRUE;
}
@@ -608,12 +608,12 @@ get_text_props(buf_T *buf, linenr_T lnum, char_u **props, int will_change)
}
/*
- * Return the number of text properties with "below" alignment in line "lnum".
- * A "right" aligned property also goes below after a "below" or other "right"
- * aligned property.
+ * Return the number of text properties with "above" or "below" alignment in
+ * line "lnum". A "right" aligned property also goes below after a "below" or
+ * other "right" aligned property.
*/
int